﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI;
using System.Data;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Shared.DataAccess;
using Vevo.Domain.GoogleFeed;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class GoogleFeedTagValueRepositoryNoCache : IGoogleFeedTagValueRepository
    {
        #region Private

        private const string AllGoogleTagValueField = " GoogleFeedTagValueID, ValueName, GoogleFeedTagValue.GoogleFeedTagID, TagName, GoogleFeedTagTypeID ";

        private GoogleFeedTagValue Create( GoogleFeedTagValue googleFeedTagValue )
        {
            string googleFeedTagValueID = DataAccess.ExecuteScalar(
                "INSERT INTO GoogleFeedTagValue(ValueName, GoogleFeedTagID) " +
                "VALUES ( @ValueName, @GoogleFeedTagID );" +
                "SELECT @@Identity; ",
                DataAccess.CreateParameterString( googleFeedTagValue.ValueName ),
                DataAccess.CreateParameterString( googleFeedTagValue.GoogleFeedTagID ) );

            googleFeedTagValue.GoogleFeedTagValueID = googleFeedTagValueID;

            return googleFeedTagValue;
        }

        private GoogleFeedTagValue Update( GoogleFeedTagValue googleFeedTagValue )
        {
            int update = DataAccess.ExecuteNonQuery(
                "UPDATE GoogleFeedTagValue " +
                "SET ValueName = @ValueName, GoogleFeedTagID = @GoogleFeedTagID " +
                "WHERE GoogleFeedTagValueID = @GoogleFeedTagValueID; ",
                DataAccess.CreateParameterString( googleFeedTagValue.ValueName ),
                DataAccess.CreateParameterString( googleFeedTagValue.GoogleFeedTagID ),
                DataAccess.CreateParameterString( googleFeedTagValue.GoogleFeedTagValueID ) );

            return googleFeedTagValue;
        }

        private GoogleFeedTagValue CreateOneFromRow( DataRow row )
        {
            GoogleFeedTagValue googleFeedTagValue = new GoogleFeedTagValue();
            googleFeedTagValue.GoogleFeedTagValueID = row["GoogleFeedTagValueID"].ToString();
            googleFeedTagValue.ValueName = row["ValueName"].ToString();
            googleFeedTagValue.GoogleFeedTagID = row["GoogleFeedTagID"].ToString();

            return googleFeedTagValue;
        }

        private IList<GoogleFeedTagValue> ConvertTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<GoogleFeedTagValue> list = new List<GoogleFeedTagValue>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( table.Rows[i] ) );

            return list;
        }

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else if (sortBy.Trim().ToLower().StartsWith( "GoogleFeedTag" ))
                return "ORDER BY GoogleFeedTagValue." + sortBy.Trim() + " ";
            else
                return "ORDER BY " + sortBy + " ";
        }

        #endregion

        #region Public

        public GoogleFeedTagValue Save( GoogleFeedTagValue googleFeedTagValue )
        {
            GoogleFeedTagValue result = GetOne( googleFeedTagValue.GoogleFeedTagValueID );

            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                if (result.IsNull)
                    result = Create( googleFeedTagValue );
                else
                    result = Update( googleFeedTagValue );

                transaction.Complete();
            }

            return result;
        }

        public GoogleFeedTagValue GetOne( string googleFeedTagValueID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllGoogleTagValueField +
                "FROM GoogleFeedTagValue LEFT JOIN " +
                "    (SELECT * FROM GoogleFeedTag) L " +
                "    ON GoogleFeedTagValue.GoogleFeedTagID = L.GoogleFeedTagID " +
                "WHERE GoogleFeedTagValue.GoogleFeedTagValueID = @GoogleFeedTagValueID ",
                DataAccess.CreateParameterString( googleFeedTagValueID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return GoogleFeedTagValue.Null;
        }

        public IList<GoogleFeedTagValue> GetAll()
        {
            return GetAll( String.Empty );
        }

        public IList<GoogleFeedTagValue> GetAll( string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllGoogleTagValueField +
                "FROM GoogleFeedTagValue LEFT JOIN " +
                "    (SELECT * FROM GoogleFeedTag) L " +
                "    ON GoogleFeedTagValue.GoogleFeedTagID = L.GoogleFeedTagID " +
                CreateSortByText( sortBy ) + "; " );

            return ConvertTableToList( table, 0, table.Rows.Count );
        }

        public IList<GoogleFeedTagValue> GetAllByTagID( string googleFeedTagID )
        {
            return GetAllByTagID( googleFeedTagID, string.Empty );
        }

        public IList<GoogleFeedTagValue> GetAllByTagID( string googleFeedTagID, string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllGoogleTagValueField +
                "FROM GoogleFeedTagValue LEFT JOIN " +
                "    (SELECT * FROM GoogleFeedTag) L " +
                "    ON GoogleFeedTagValue.GoogleFeedTagID = L.GoogleFeedTagID " +
                "WHERE GoogleFeedTagValue.GoogleFeedTagID = @GoogleFeedTagID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.CreateParameterString( googleFeedTagID ) );

            return ConvertTableToList( table, 0, table.Rows.Count );
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllGoogleTagValueField +
                "FROM GoogleFeedTagValue LEFT JOIN " +
                "    (SELECT * FROM GoogleFeedTag) L " +
                "    ON GoogleFeedTagValue.GoogleFeedTagID = L.GoogleFeedTagID " +
                "WHERE 1 = 0 " );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        public void Delete( string googleFeedTagValueID )
        {
            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                DataAccess.ExecuteNonQuery(
                "DELETE FROM GoogleFeedTagValue WHERE GoogleFeedTagValueID = @GoogleFeedTagValueID;",
                DataAccess.CreateParameterString( googleFeedTagValueID ) );

                transaction.Complete();
            }
        }

        #endregion
    }
}
