﻿using System.Collections.Generic;
using System.IO;
using Vevo.Domain.Products;

namespace Vevo.Domain.ImportExport
{
    public class ProductSpecificationExporter
    {
        private string GenerateHeader()
        {
            return "\"Sku\",\"SpecificationItemID\",\"Value\"";
        }

        private string GenerateDetail( ProductSpecification spec, Culture culture, string storeID )
        {
            string sku = DataAccessContext.ProductRepository.GetOne( culture, spec.ProductID, storeID ).Sku;
            string specificationItemID = spec.SpecificationItemID;
            string value = spec.Value;

            return sku + "," + specificationItemID + "," + value;
        }

        public MemoryStream ExportToStream( IList<ProductSpecification> specList, Culture culture, string storeID )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream );

            if (specList.Count > 0)
            {
                sw.WriteLine( GenerateHeader() );
                string details;
                foreach (ProductSpecification spec in specList)
                {
                    details = GenerateDetail( spec, culture, storeID );
                    sw.WriteLine( details );
                }
            }

            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }
    }
}
