﻿using System;
using System.Collections.Generic;
using Vevo.Domain.Base;

namespace Vevo.Domain.Products
{
    public class Manufacturer : ILocaleLoader, ICloneable
    {
        #region Private

        // Members for properties
        private string _manufacturerID = "0";
        private string _urlName = String.Empty;
        private int _sortOrder = 0;
        private bool _isEnabled = true;
        private bool _isShowNewArrival = true;
        private int _newArrivalAmount = 9;

        private Culture _defaultCulture;
        private LocaleCollection<ManufacturerLocale> _locales;

        #endregion

         #region Public Constructors

        public Manufacturer( Culture defaultCulture )
        {
            _defaultCulture = defaultCulture;
            _locales = new LocaleCollection<ManufacturerLocale>( this );
        }

        public Manufacturer()
        {
            _defaultCulture = new Culture();
            _locales = new LocaleCollection<ManufacturerLocale>( this );
        }

        #endregion

        #region Public Properties

        public static Manufacturer Null
        {
            get { return NullManufacturer.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string ManufacturerID { get { return _manufacturerID; } set { _manufacturerID = value; } }
        public string UrlName { get { return _urlName; } set { _urlName = value; } }
        public bool IsEnabled { get { return _isEnabled; } set { _isEnabled = value; } }
        public bool IsShowNewArrival { get { return _isShowNewArrival; } set { _isShowNewArrival = value; } }
        public int SortOrder { get { return _sortOrder; } set { _sortOrder = value; } }
        public int NewArrivalAmount { get { return _newArrivalAmount; } set { _newArrivalAmount = value; } }
        public Culture DefaultCulture { get { return _defaultCulture; } set { _defaultCulture = value; } }
        public LocaleCollection<ManufacturerLocale> Locales { get { return _locales; } }

        //------------------------------------------------------------
        // Locale items
        public string Name
        {
            get { return Locales[DefaultCulture].Name; }
            set { Locales.GetNoLoad( DefaultCulture ).Name = value; }
        }
        public string Description
        {
            get { return Locales[DefaultCulture].Description; }
            set { Locales.GetNoLoad( DefaultCulture ).Description = value; }
        }
        public string LongDescription
        {
            get { return Locales[DefaultCulture].LongDescription; }
            set { Locales.GetNoLoad( DefaultCulture ).LongDescription = value; }
        }
        public string MetaKeyword
        {
            get { return Locales[DefaultCulture].MetaKeyword; }
            set { Locales.GetNoLoad( DefaultCulture ).MetaKeyword = value; }
        }
        public string MetaDescription
        {
            get { return Locales[DefaultCulture].MetaDescription; }
            set { Locales.GetNoLoad( DefaultCulture ).MetaDescription = value; }
        }
        public string ImageAlt
        {
            get { return Locales[DefaultCulture].ImageAlt; }
            set { Locales.GetNoLoad( DefaultCulture ).ImageAlt = value; }
        }
        public string ImageTitle
        {
            get { return Locales[DefaultCulture].ImageTitle; }
            set { Locales.GetNoLoad( DefaultCulture ).ImageTitle = value; }
        }
        public string ImageFile
        {
            get { return Locales[DefaultCulture].ImageFile; }
            set { Locales.GetNoLoad( DefaultCulture ).ImageFile = value; }
        }
        // End Locale items
        //------------------------------------------------------------

        #endregion

        #region IClonable Members

        public object Clone()
        {
            Manufacturer newObject = (Manufacturer) MemberwiseClone();
            newObject._locales = (LocaleCollection<ManufacturerLocale>) _locales.Clone();

            return newObject;
        }

        #endregion

        #region ILocaleLoader Members

        public IList<ILocale> GetLocales()
        {
            List<ILocale> result = new List<ILocale>();
            foreach (ManufacturerLocale locale in DataAccessContext.ManufacturerRepository.GetLocales( ManufacturerID ))
                result.Add( locale );

            return result;
        }
        #endregion

        #region Public Methods
        public string GetMetaDescription( Culture culture )
        {
            if (!String.IsNullOrEmpty( Locales[culture].MetaDescription ))
                return Locales[culture].MetaDescription;
            else
                return Locales[culture].Description;
        }

        public string GetMetaKeyword( Culture culture )
        {
            if (!String.IsNullOrEmpty( Locales[culture].MetaKeyword ))
                return Locales[culture].MetaKeyword;
            else
                return Locales[culture].Name;
        }

        #endregion
    }
}
