using System;
using Vevo.Domain;
using Vevo.Domain.Users;
using Vevo.Domain.Products;
using Vevo.QuickBooks.Qbxml70;
using Vevo.Domain.Orders;
using System.Collections.Generic;
using System.Web;

namespace Vevo.QuickBooks.States
{
    /// <summary>
    /// Summary description for OrderAddRequestState
    /// </summary>
    public class OrderAddRequestState : QBWCState
    {
        private void MoveToNextState()
        {
            QBWCSession.CurrentState = new OrderAddResponseState( QBWCSession );
        }

        private IList<Order> GetAddData()
        {
            string storeID = getStoreID();
            
            IList<Order> table = DataAccessContext.OrderRepository.GetByIsQBExported( false, storeID, String.Empty );
            return table;
        }

        private string getStoreID()
        {
            return DataAccessContext.Configurations.GetValue( "QBSelectStoreExport" );
        }

        private string GetCustomerListID( string customerID )
        {
            if (customerID.ToString() == "0")
            {
                return DataAccessContext.Configurations.GetValue( "QBAnonymousListID" );
            }
            else
            {
                Customer customer = DataAccessContext.CustomerRepository.GetOne( customerID );
                return customer.QBListID;
            }
        }

        private string GetCustomerTax( string customerID )
        {
            Customer customer = DataAccessContext.CustomerRepository.GetOne( customerID );
            if (customer.IsTaxExempt)
                return "Non";
            else
                return "Tax";
        }

        private Product GetProduct( string productID )
        {
            string cultureID = DataAccessContext.CultureRepository.GetIDByName(
                DataAccessContext.Configurations.GetValue( "DefaultWebsiteLanguage" ) );
            Culture culture = DataAccessContext.CultureRepository.GetOne( cultureID );

            string storeID = DataAccessContext.Configurations.GetValue( "QBSelectStoreExport" );
            Product product = DataAccessContext.ProductRepository.GetOne( culture, productID, storeID );

            return product;
        }

        private string GetOrderDate( DateTime orderDate )
        {
            return orderDate.ToString( "yyyy-MM-dd" );
        }

        private string GetTaxCode( string TaxClassID )
        {
            if (TaxClassID.Equals( "0" ))
                return "Non";
            else
                return "Tax";
        }

        private SalesReceiptLineAdd AddDiscountItem( decimal discount )
        {
            SalesReceiptLineAdd itemReceipt = new SalesReceiptLineAdd();

            ItemRef item = new ItemRef();
            item.FullName = DataAccessContext.Configurations.GetValue( "QBDiscountItem" );
            itemReceipt.ItemRef = item;

            itemReceipt.Amount = discount.ToString( "F" );

            return itemReceipt;
        }

        private SalesReceiptLineAdd AddShippingItem( decimal shipping )
        {
            SalesReceiptLineAdd itemReceipt = new SalesReceiptLineAdd();

            ItemRef item = new ItemRef();
            item.FullName = DataAccessContext.Configurations.GetValue( "QBShippingItem" );
            itemReceipt.ItemRef = item;

            itemReceipt.Amount = shipping.ToString( "F" );

            return itemReceipt;
        }

        private string GetProductOption( string orderName )
        {
            string[] splitKeywordList = { "<br>" };
            string[] option;
            string productOption = String.Empty;

            option = orderName.Split( splitKeywordList, StringSplitOptions.RemoveEmptyEntries );

            for (int i = 1; i < option.Length; i++)
            {
                productOption += option[i];
                productOption += ", ";
            }

            return productOption;
        }

        public SalesReceiptAddRqType CreateOneRequest( Order order )
        {
            string orderName = CreateUniqueName( order.OrderID ); 
            SalesReceiptAddRqType req = new SalesReceiptAddRqType();            
            req.SalesReceiptAdd = new SalesReceiptAdd();

            req.SalesReceiptAdd.Memo = order.InvoiceNotes;
            req.SalesReceiptAdd.TxnDate = GetOrderDate( order.OrderDate );
            req.SalesReceiptAdd.RefNumber = orderName;

            CustomerRef customer = new CustomerRef();
            customer.ListID = GetCustomerListID( order.CustomerID );
            req.SalesReceiptAdd.CustomerRef = customer;
            if (!String.IsNullOrEmpty( order.CustomerComments ))
            {
                CustomerMsgRef msg = new CustomerMsgRef();
                msg.FullName = order.CustomerComments;
                req.SalesReceiptAdd.CustomerMsgRef = msg;
            }

            CustomerSalesTaxCodeRef customerTax = new CustomerSalesTaxCodeRef();
            customerTax.FullName = GetCustomerTax( order.CustomerID );
            req.SalesReceiptAdd.CustomerSalesTaxCodeRef = customerTax;

            ItemSalesTaxRef salesTax = new ItemSalesTaxRef();
            salesTax.FullName = DataAccessContext.Configurations.GetValue( "QBTaxItem" );
            req.SalesReceiptAdd.ItemSalesTaxRef = salesTax;

            BillAddress billAddress = new BillAddress();
            billAddress.Addr1 = QBUtilities.LimitLength( order.Billing.Address1, QBConst.AddressLineMaxLength );
            billAddress.Addr2 = QBUtilities.LimitLength( order.Billing.Address2, QBConst.AddressLineMaxLength );
            billAddress.City = QBUtilities.LimitLength( order.Billing.City, QBConst.CityMaxLength );
            billAddress.State = QBUtilities.LimitLength( order.Billing.State, QBConst.StateMaxLength );
            billAddress.PostalCode = QBUtilities.LimitLength( order.Billing.Zip, QBConst.ZipMaxLength );
            billAddress.Country = QBUtilities.LimitLength( order.Billing.Country, QBConst.CountryMaxLength );
            req.SalesReceiptAdd.BillAddress = billAddress;

            ShipAddress shipAddress = new ShipAddress();
            shipAddress.Addr1 = QBUtilities.LimitLength( order.Shipping.Address1, QBConst.AddressLineMaxLength );
            shipAddress.Addr2 = QBUtilities.LimitLength( order.Shipping.Address2, QBConst.AddressLineMaxLength );
            shipAddress.City = QBUtilities.LimitLength( order.Shipping.City, QBConst.CityMaxLength );
            shipAddress.State = QBUtilities.LimitLength( order.Shipping.State.ToString(), QBConst.StateMaxLength );
            shipAddress.PostalCode = QBUtilities.LimitLength( order.Shipping.Zip.ToString(), QBConst.ZipMaxLength );
            shipAddress.Country = QBUtilities.LimitLength( order.Shipping.Country.ToString(), QBConst.CountryMaxLength );
            req.SalesReceiptAdd.ShipAddress = shipAddress;

            object[] orderItem = GenerateOrderItems( order.OrderItems, order.CouponDiscount, order.ShippingCost );
            req.SalesReceiptAdd.Items = orderItem;

            QBWCSession.AddQBFullNameList( orderName, String.Empty );

            return req;
        }

        private object[] GenerateOrderItems( IList<OrderItem> orderItems, decimal discount, decimal shipping )
        {
            object[] items = new object[orderItems.Count + 2];
            int index = 0;

            foreach (OrderItem orderItem in orderItems)
            {
                Product product = GetProduct( orderItem.ProductID );
                SalesReceiptLineAdd itemReceipt = new SalesReceiptLineAdd();

                ItemRef item = new ItemRef();
                item.ListID = product.QBListID;
                itemReceipt.ItemRef = item;

                itemReceipt.Desc = QBUtilities.LimitLength(
                    GetProductOption( orderItem.Name ) + product.ShortDescription, 
                    QBConst.SalesLineDescMaxLength );

                itemReceipt.Quantity = orderItem.Quantity.ToString();
                itemReceipt.Amount = orderItem.ItemSubtotal.ToString( "F" );

                itemReceipt.SalesTaxCodeRef = new SalesTaxCodeRef();
                itemReceipt.SalesTaxCodeRef.FullName = GetTaxCode( product.TaxClassID );

                items[index] = itemReceipt;
                index++;
            }

            items[index] = AddDiscountItem( discount );
            index++;

            items[index] = AddShippingItem( shipping );
            index++;

            return items;
        }

        private string CreateOrderAdd( out bool xmlReady )
        {
            IList<Order> table = GetAddData();
            int lenght = table.Count;
            if (table.Count == 0)
            {
                xmlReady = false;
                return String.Empty;
            }
            // Write QBXML
            QBXML qbxml = CreateRequestQbxml();

            object[] requests = new object[table.Count];

            int index = 0;
            foreach (Order order in table)
            {
                requests[index] = CreateOneRequest( order );
                index++;
            }
            ((QBXMLMsgsRq) qbxml.Items[0]).Items = requests;

            xmlReady = true;
            string xml = CreateRequestXml( qbxml );
            return xml;
        }
        public OrderAddRequestState( QBWCSession session )
            : base( session )
        {
        }

        public override string OnSendRequestXml( out bool xmlReady )
        {
            string xml = CreateOrderAdd( out xmlReady );
            if (xmlReady)
                MoveToNextState();

            return xml;
        }
    }
}