using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.IO;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace Vevo.WebUI.ServerControls
{
    [DefaultProperty( "ImageUrl" )]
    [ToolboxData( "<{0}:Image runat=server></{0}:Image>" )]
    public class Image : System.Web.UI.WebControls.Image
    {
        private bool IsMaximumWidthValid()
        {
            return !MaximumWidth.IsEmpty &&
                MaximumWidth.Type == UnitType.Pixel;
        }

        private bool IsMaximumHeightValid()
        {
            return !MaximumHeight.IsEmpty &&
                MaximumHeight.Type == UnitType.Pixel;
        }

        private void SetUpImage()
        {
            if (!String.IsNullOrEmpty( ImageUrl ))
            {
                //ImageUrl = Page.ResolveUrl( ImageUrl );

                if (IsMaximumWidthValid() ||
                    IsMaximumHeightValid())
                {
                    if (File.Exists( HttpContext.Current.Server.MapPath( ImageUrl ) ))
                    {
                        using (Bitmap mypic = new Bitmap( HttpContext.Current.Server.MapPath( ImageUrl ) ))
                        {
                            if (IsMaximumWidthValid() &&
                                IsMaximumHeightValid() &&
                                mypic.Width > MaximumWidth.Value &&
                                mypic.Height > MaximumHeight.Value)
                            {
                                double pictureRatio = (double) mypic.Width / mypic.Height;
                                double customRatio = (double) MaximumWidth.Value / MaximumHeight.Value;

                                if (pictureRatio > customRatio)
                                {
                                    Width = MaximumWidth;
                                }
                                else
                                {
                                    Height = MaximumHeight;
                                }
                            }
                            else
                            {
                                if (IsMaximumWidthValid() &&
                                    mypic.Width > MaximumWidth.Value)
                                {
                                    Width = MaximumWidth;
                                }
                                else if (IsMaximumHeightValid() &&
                                    mypic.Height > MaximumHeight.Value)
                                {
                                    Height = MaximumHeight;
                                }
                            }
                        }
                    }
                }
            }
        }


        protected void Control_PreRender( object sender, EventArgs e )
        {
            if (!String.IsNullOrEmpty( ImageUrl ))
            {
                SetUpImage();
            }
            else if (!String.IsNullOrEmpty( DefaultImageUrl ))
            {
                ImageUrl = DefaultImageUrl;
            }
        }


        public Image()
        {
            PreRender += new EventHandler( Control_PreRender );
        }

        public Unit MaximumWidth
        {
            get
            {
                if (ViewState["MaximumWidth"] != null)
                    return (Unit) ViewState["MaximumWidth"];
                else
                    return Unit.Empty;
            }
            set
            {
                ViewState["MaximumWidth"] = value;
            }
        }

        public Unit MaximumHeight
        {
            get
            {
                if (ViewState["MaximumHeight"] != null)
                    return (Unit) ViewState["MaximumHeight"];
                else
                    return Unit.Empty;
            }
            set
            {
                ViewState["MaximumHeight"] = value;
            }
        }

        public string DefaultImageUrl
        {
            get
            {
                if (ViewState["DefaultImageUrl"] != null)
                    return (string) ViewState["DefaultImageUrl"];
                else
                    return String.Empty;
            }
            set
            {
                ViewState["DefaultImageUrl"] = value;
            }
        }

    }
}
