using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Web;
using Vevo.DataAccessLib;
using Vevo.DataAccessLib.Cart;
using Vevo.Domain;
using Vevo.Shared.DataAccess;
using Vevo.WebAppLib;
using Vevo.WebUI.DataAccessCache;

namespace Vevo.WebUI.DataAccessCache
{
    public interface IAdminMenuAdvancedAccessCache
    {
        DataTable GetAllByAdminID(
            string cultureID,
            string adminID,
            string sortBy,
            FlagFilter isEnabled );

        DataTable GetAll( string cultureID, string sortBy, FlagFilter isEnabled );
    }


    /// <summary>
    /// Summary description for AdminMenuAdvancedCache
    /// </summary>
    public static class AdminMenuAdvancedAccessCache
    {
        private static CachedAdminMenuAdvancedObject _cachedObject = new CachedAdminMenuAdvancedObject();
        private static NonCachedAdminMenuAdvancedObject _nonCachedObject = new NonCachedAdminMenuAdvancedObject();


        public static IAdminMenuAdvancedAccessCache Instance
        {
            get
            {
                if (DataAccessContext.Configurations.GetBoolValueNoThrow( "AdminCachingEnabled" ))
                    return _cachedObject;
                else
                    return _nonCachedObject;
            }
        }

        public static void ClearCache()
        {
            _cachedObject.ClearCache();
        }



        //----------------------------------------------------------------------------------
        // CachedAdminMenuAdvancedObject
        //----------------------------------------------------------------------------------

        private class CachedAdminMenuAdvancedObject : BaseDataAccessCache, IAdminMenuAdvancedAccessCache
        {
            public CachedAdminMenuAdvancedObject()
                : base( "AdminMenuAdvancedAccess" )
            {
            }

            public DataTable GetAllByAdminID(
                string cultureID,
                string adminID,
                string sortBy,
                FlagFilter isEnabled )
            {
                return (DataTable) CachedMethod(
                    "GetAllByAdminID",
                    AdminMenuAdvancedAccess.GetAllByAdminID,
                    cultureID,
                    adminID,
                    sortBy,
                    isEnabled );
            }

            public DataTable GetAll( string cultureID, string sortBy, FlagFilter isEnabled )
            {
                return (DataTable) CachedMethod(
                    "GetAll",
                    AdminMenuAdvancedAccess.GetAll,
                    cultureID,
                    sortBy,
                    isEnabled );
            }

        }

        //----------------------------------------------------------------------------------
        // NonCachedAdminMenuAdvancedObject
        //----------------------------------------------------------------------------------

        private class NonCachedAdminMenuAdvancedObject : IAdminMenuAdvancedAccessCache
        {
            public DataTable GetAllByAdminID(
                string cultureID,
                string adminID,
                string sortBy,
                FlagFilter isEnabled )
            {
                return AdminMenuAdvancedAccess.GetAllByAdminID( cultureID, adminID, sortBy, isEnabled );
            }

            public DataTable GetAll( string cultureID, string sortBy, FlagFilter isEnabled )
            {
                return AdminMenuAdvancedAccess.GetAll( cultureID, sortBy, isEnabled );
            }

        }
    }
}
