using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Web;
using Vevo.DataAccessLib;
using Vevo.DataAccessLib.Cart;
using Vevo.Domain;
using Vevo.WebAppLib;

namespace Vevo.WebUI.DataAccessCache
{
    public interface IAdminMenuPageAccessCache
    {
        DataTable GetAll( string cultureID );
    }


    /// <summary>
    /// Summary description for AdminMenuItemAccessCache
    /// </summary>
    public static class AdminMenuPageAccessCache
    {
        private static CachedAdminMenuPageAccessObject _cachedObject = new CachedAdminMenuPageAccessObject();
        private static NonCachedAdminMenuPageAccessObject _nonCachedObject = new NonCachedAdminMenuPageAccessObject();


        public static IAdminMenuPageAccessCache Instance
        {
            get
            {
                if (DataAccessContext.Configurations.GetBoolValueNoThrow( "AdminCachingEnabled" ))
                    return _cachedObject;
                else
                    return _nonCachedObject;
            }
        }

        public static void ClearCache()
        {
            _cachedObject.ClearCache();
        }



        //----------------------------------------------------------------------------------
        // CachedAdminMenuPageAccessObject
        //----------------------------------------------------------------------------------

        private class CachedAdminMenuPageAccessObject : BaseDataAccessCache, IAdminMenuPageAccessCache
        {
            public CachedAdminMenuPageAccessObject()
                : base( "AdminMenuPageAccess" )
            {
            }

            public DataTable GetAll( string cultureID )
            {
                return (DataTable) CachedMethod( "GetAll", AdminMenuPageAccess.GetAll, cultureID );
            }

        }

        //----------------------------------------------------------------------------------
        // NonCachedAdminMenuItemAccessObject
        //----------------------------------------------------------------------------------

        private class NonCachedAdminMenuPageAccessObject : IAdminMenuPageAccessCache
        {
            public DataTable GetAll( string cultureID )
            {
                return AdminMenuPageAccess.GetAll( cultureID );
            }

        }
    }
}
