﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI.WebControls;
using Vevo.Domain;
using Vevo.Domain.Products;

namespace Vevo.WebUI.Products
{
    public class DepartmentNavMenuBuilder
    {
        #region Private

        private Culture _culture;
        private GetDepartmentUrlFunc _getDepartmentUrl;
        private int _maxNodeDepth;

        private void PopulateDepartments( int nodeDepth, MenuItem item, string parentDepartmentID )
        {
            IList<Department> list = DataAccessContext.DepartmentRepository.GetByParentID(
                _culture,
                parentDepartmentID,
                "SortOrder",
                BoolFilter.ShowTrue );

            foreach (Department department in list)
            {
                item.ChildItems.Add( CreateMenuItemTree( nodeDepth, department ) );
            }
        }

        private MenuItem CreateMenuItemTree( int nodeDepth, Department department )
        {
            MenuItem newItem = new MenuItem();
            newItem.Text = department.Name;
            newItem.Value = department.DepartmentID;

            if (DataAccessContext.DepartmentRepository.IsDepartmentIDNotLeaf( department.DepartmentID ))
            {
                newItem.NavigateUrl = _getDepartmentUrl( department.DepartmentID, department.UrlName );

                if (nodeDepth < _maxNodeDepth)
                    PopulateDepartments( nodeDepth + 1, newItem, department.DepartmentID );
            }
            else
            {
                newItem.NavigateUrl = _getDepartmentUrl( department.DepartmentID, department.UrlName );
            }
            return newItem;
        }

        #endregion


        #region Constructors

        public delegate string GetDepartmentUrlFunc( object departmentID, object urlName );

        public DepartmentNavMenuBuilder( Culture culture, GetDepartmentUrlFunc getDepartmentUrl, int maxNodeDepth )
        {
            _culture = culture;
            _getDepartmentUrl = getDepartmentUrl;
            _maxNodeDepth = maxNodeDepth;
        }

        #endregion


        #region Public Methods

        public MenuItem CreateMenuItemTree( Department department )
        {
            return CreateMenuItemTree( 1, department );
        }

        #endregion

    }
}

